@@ -21,7 +21,7 @@ from torch.utils.data import DataLoader
 from torch.utils.data import random_split
 
 import pytorch_lightning as pl
-from pl_examples import TORCHVISION_AVAILABLE
+from pl_examples import TORCHVISION_AVAILABLE, cli_lightning_logo
 
 if TORCHVISION_AVAILABLE:
     from torchvision.datasets.mnist import MNIST
@@ -31,6 +31,13 @@ else:
 
 
 class LitAutoEncoder(pl.LightningModule):
+    """
+    >>> LitAutoEncoder()  # doctest: +ELLIPSIS +NORMALIZE_WHITESPACE
+    LitAutoEncoder(
+      (encoder): ...
+      (decoder): ...
+    )
+    """
 
     def __init__(self):
         super().__init__()
@@ -105,4 +112,5 @@ def cli_main():
 
 
 if __name__ == '__main__':
+    cli_lightning_logo()
     cli_main()
