@@ -77,6 +77,7 @@ class CometLogger(LightningLoggerBase):
             save_dir='.',  # Optional
             project_name='default_project',  # Optional
             rest_api_key=os.environ.get('COMET_REST_API_KEY'),  # Optional
+            experiment_key=os.environ.get('COMET_EXPERIMENT_KEY'),  # Optional
             experiment_name='default'  # Optional
         )
         trainer = Trainer(logger=comet_logger)
@@ -113,20 +114,24 @@ class CometLogger(LightningLoggerBase):
             the experiment will be in online or offline mode. This is useful if you use
             save_dir to control the checkpoints directory and have a ~/.comet.config
             file but still want to run offline experiments.
+        prefix: A string to put at the beginning of metric keys.
         \**kwargs: Additional arguments like `workspace`, `log_code`, etc. used by
             :class:`CometExperiment` can be passed as keyword arguments in this logger.
     """
 
+    LOGGER_JOIN_CHAR = '-'
+
     def __init__(
-            self,
-            api_key: Optional[str] = None,
-            save_dir: Optional[str] = None,
-            project_name: Optional[str] = None,
-            rest_api_key: Optional[str] = None,
-            experiment_name: Optional[str] = None,
-            experiment_key: Optional[str] = None,
-            offline: bool = False,
-            **kwargs
+        self,
+        api_key: Optional[str] = None,
+        save_dir: Optional[str] = None,
+        project_name: Optional[str] = None,
+        rest_api_key: Optional[str] = None,
+        experiment_name: Optional[str] = None,
+        experiment_key: Optional[str] = None,
+        offline: bool = False,
+        prefix: str = '',
+        **kwargs
     ):
         if comet_ml is None:
             raise ImportError(
@@ -159,6 +164,7 @@ class CometLogger(LightningLoggerBase):
         self._project_name = project_name
         self._experiment_key = experiment_key
         self._experiment_name = experiment_name
+        self._prefix = prefix
         self._kwargs = kwargs
         self._future_experiment_key = None
 
@@ -238,6 +244,7 @@ class CometLogger(LightningLoggerBase):
 
         metrics_without_epoch = metrics.copy()
         epoch = metrics_without_epoch.pop('epoch', None)
+        metrics_without_epoch = self._add_prefix(metrics_without_epoch)
         self.experiment.log_metrics(metrics_without_epoch, step=step, epoch=epoch)
 
     def reset_experiment(self):
